Module blaxel.models.request_total_metric
=========================================

Classes
-------

`RequestTotalMetric(request_total: blaxel.types.Unset | float = <blaxel.types.Unset object>, request_total_per_code: blaxel.types.Unset | ForwardRef('RequestTotalMetricRequestTotalPerCode') = <blaxel.types.Unset object>, rps: blaxel.types.Unset | float = <blaxel.types.Unset object>, rps_per_code: blaxel.types.Unset | ForwardRef('RequestTotalMetricRpsPerCode') = <blaxel.types.Unset object>)`
:   Metrics for request total
    
    Attributes:
        request_total (Union[Unset, float]): Number of requests for all resources globally
        request_total_per_code (Union[Unset, RequestTotalMetricRequestTotalPerCode]): Number of requests for all
            resources globally per code
        rps (Union[Unset, float]): Number of requests per second for all resources globally
        rps_per_code (Union[Unset, RequestTotalMetricRpsPerCode]): Number of requests for all resources globally
    
    Method generated by attrs for class RequestTotalMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `request_total`
    :

    `request_total_per_code`
    :

    `rps`
    :

    `rps_per_code`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :